@@ -1,7 +1,7 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (C) 2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "addresseslocationenginepage.h"
 #include <QWebEngineSettings>
+#include <QWebEngineProfile>
 
 using namespace Akonadi;
 
@@ -37,6 +38,19 @@ AddressesLocationEnginePage::AddressesLocationEnginePage(QObject *parent)
     settings()->setAttribute(QWebEngineSettings::ErrorPageEnabled, false);
     settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, false);
     settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, false);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+    settings()->setAttribute(QWebEngineSettings::ScreenCaptureEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::AutoLoadIconsForPage, false);
+    settings()->setAttribute(QWebEngineSettings::Accelerated2dCanvasEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
+#endif
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+    settings()->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::AllowRunningInsecureContent, false);
+#endif
+    profile()->setPersistentCookiesPolicy(QWebEngineProfile::NoPersistentCookies);
 
 }
 
