@@ -1,7 +1,7 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (C) 2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -28,7 +28,7 @@ class MessagingWidgetTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit MessagingWidgetTest(QObject *parent = Q_NULLPTR);
+    explicit MessagingWidgetTest(QObject *parent = nullptr);
     ~MessagingWidgetTest();
 private Q_SLOTS:
     void shouldHaveDefaultValues();
