@@ -2,7 +2,7 @@
     This file is part of Akonadi Contact.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -128,9 +128,7 @@ KContacts::ResourceLocatorUrl WebWidget::url()
             value.append(QStringLiteral("PREF"));
         }
     } else {
-        if (value.contains(QStringLiteral("PREF"))) {
-            value.removeAll(QStringLiteral("PREF"));
-        }
+        value.removeAll(QStringLiteral("PREF"));
     }
     if (!value.isEmpty()) {
         parameters.insert(QStringLiteral("type"), value);
@@ -147,7 +145,8 @@ void WebWidget::loadWebSite(const KContacts::ResourceLocatorUrl &url)
     if (value.contains(QStringLiteral("PREF"))) {
         setPreferred(true);
     }
-    Q_FOREACH (const QString &type, mWebType->selectTypeList()) {
+    const QStringList lst = mWebType->selectTypeList();
+    for (const QString &type : lst) {
         if (value.contains(type)) {
             mOldType = type;
             mWebType->setCurrentIndex(mWebType->findData(type));
